<?php

declare(strict_types=1);

namespace Drupal\field_ipaddress_pgsql\Plugin\Validation\Constraint;

use IPTools\Exception\IpException;
use IPTools\Exception\NetworkException;
use IPTools\Network;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validates the MySQL format validation constraint.
 */
final class MySqlFormatConstraintValidator extends ConstraintValidator {

  /**
   * Validate the IP address.
   */
  public function validate(mixed $field, Constraint $constraint): void {
    $value = trim($field->value);

    try {
      /** @var \IPTools\IP $ipAddress */
      $ipAddress = Network::parse($value)->getIP();
    }
    catch (IpException $e) {
      $this->context->addViolation($constraint->messageIpAddressFormat);
      return;
    }
    catch (NetworkException $e) {
      $this->context->addViolation($constraint->messagePrefixLength);
      return;
    }

    /** @var \Drupal\Core\Field\FieldItemListInterface $field */
    $settings = $field->getFieldDefinition()->getSettings();

    if ($settings['family'] == 4) {
      if ($ipAddress->getVersion() !== $ipAddress::IP_V4) {
        $this->context->addViolation($constraint->messageIpV4);
        return;
      }
    }
    elseif ($ipAddress->getVersion() !== $ipAddress::IP_V6) {
      $this->context->addViolation($constraint->messageIpV6);
      return;
    }

    if ($settings['cidr_format']) {
      $network = (string) Network::parse($value)->getNetwork();
      $ipAddress = (string) $ipAddress;
      if ($ipAddress !== $network) {
        $this->context->addViolation($constraint->messageCidr);
      }
    }

  }

}
